pub enum Classification {
Retryable,
Terminal,
}Expand description
Explicit retryability classification for an activity failure.
Variants
Retryable
The engine may retry the activity according to policy.
Terminal
The activity failure is permanent and must not be retried.