decode_payload

Function decode_payload 

pub fn decode_payload<T>(payload: &Payload) -> Result<T, WorkerError>
Decodes a payload into a typed value using the payload content-type tag.

Errors

Returns WorkerError::Decode when the payload tag or bytes cannot produce the requested type.