pub type TypedActivityDispatcher = ActivityRegistry;Expand description
Backwards-compatible name for the typed activity registry used by the runtime.
Aliased Type
pub struct TypedActivityDispatcher { /* private fields */ }pub type TypedActivityDispatcher = ActivityRegistry;Backwards-compatible name for the typed activity registry used by the runtime.
pub struct TypedActivityDispatcher { /* private fields */ }