default_node

Function default_node 

pub fn default_node() -> String
Resolve the machine hostname for use as the default node locality affinity.

Falls back to [DEFAULT_WORKER_NODE] (never panics) when the OS hostname is unavailable or is not valid UTF-8.