ProcessGroupError

Enum ProcessGroupError 

pub enum ProcessGroupError {
    Unsupported,
    Spawn {
        source: Error,
    },
    MissingProcessId,
    ProcessIdOutOfRange {
        pid: u32,
    },
    MissingPipe {
        stream: &'static str,
    },
    Read {
        stream: &'static str,
        source: Error,
    },
    Reap {
        source: Error,
    },
    Signal {
        process_group: i32,
        signal: &'static str,
        source: Errno,
    },
    Probe {
        process_group: i32,
        source: Errno,
    },
    GroupStillAlive {
        process_group: i32,
        grace: Duration,
    },
    CleanupAfterFailure {
        original: Box<ProcessGroupError>,
        cleanup: Box<ProcessGroupError>,
    },
}
A failure to start, observe, or completely stop a contained command.

Variants



Unsupported

Process-group containment is unavailable on this target.



Spawn

The command could not be spawned.

Fields

source: Error

Underlying spawn failure.



MissingProcessId

The spawned child did not expose a process id.



ProcessIdOutOfRange

The platform process id did not fit the Unix pid_t representation.

Fields

pid: u32

Process id returned by Tokio.



MissingPipe

A configured output pipe was unexpectedly unavailable.

Fields

stream: &'static str

Name of the missing stream.



Read

Reading a captured output stream failed.

Fields

stream: &'static str

Name of the failed stream.

source: Error

Underlying read failure.



Reap

Waiting for or reaping the direct child failed.

Fields

source: Error

Underlying wait failure.



Signal

Sending a signal to the process group failed.

Fields

process_group: i32

Process group that should have received the signal.

signal: &'static str

Signal being sent.

source: Errno

Underlying Unix error.



Probe

Probing process-group existence failed.

Fields

process_group: i32

Process group being probed.

source: Errno

Underlying Unix error.



GroupStillAlive

The group remained observable after SIGKILL and the verification bound.

Fields

process_group: i32

Process group that failed to disappear.

grace: Duration

Verification interval after SIGKILL.



CleanupAfterFailure

Command observation failed and the mandatory cleanup also failed.

Fields

original: Box<ProcessGroupError>

Original command observation failure.

cleanup: Box<ProcessGroupError>

Cleanup failure proving cancellation could not be confirmed.