High-level worker builder and run loop.
Worker builder, run loop, and shutdown wiring.
Structs
- Empty
Activity Set - Error returned when a worker is built without any registered activities.
- Worker
- Configured Rust worker with typed activity handlers.
- Worker
Builder - Builder for a configured worker and its registered typed activities.
Functions
- run_
worker_ with_ session - Connects and serves an already-built worker with the default non-shutdown future.