pub struct WorkerBuilder { /* private fields */ }Expand description
Builder for a configured worker and its registered typed activities.
Implementations
Sourceimpl WorkerBuilder
impl WorkerBuilder
Sourcepub fn new(config: WorkerConfig) -> Self
pub fn new(config: WorkerConfig) -> Self
Creates a builder for a worker using the supplied config.
Sourcepub fn register_activity<Input, Output, Handler>(
self,
activity_type: impl Into<String>,
handler: Handler,
) -> Result<Self, WorkerError>where
Input: Serialize + DeserializeOwned + Send + Sync + 'static,
Output: Serialize + Send + Sync + 'static,
Handler: for<'context> Fn(Input, &'context ActivityContext) -> HandlerFuture<'context, Output> + Send + Sync + 'static,
pub fn register_activity<Input, Output, Handler>(
self,
activity_type: impl Into<String>,
handler: Handler,
) -> Result<Self, WorkerError>where
Input: Serialize + DeserializeOwned + Send + Sync + 'static,
Output: Serialize + Send + Sync + 'static,
Handler: for<'context> Fn(Input, &'context ActivityContext) -> HandlerFuture<'context, Output> + Send + Sync + 'static,
Registers one typed activity handler on the builder.
Errors
Returns WorkerError::Registration when the activity type is duplicate.
Sourcepub fn build(self) -> Result<Worker, WorkerError>
pub fn build(self) -> Result<Worker, WorkerError>
Builds the worker after validating that it has at least one activity.
Errors
Returns WorkerError::Registration when no activities are registered.